@@ -41,6 +41,7 @@ class LinterMessage:
             self.filename,
             self.lineno,
             self.charno,
+            self.tool,
             self.message_id,
             self.message,
             self.message_id,
@@ -64,8 +65,7 @@ class LinterMessage:
             "path": self.filename,
             "row": self.lineno if self.lineno else 1,
             "col": self.charno,
-            # horrible hack for visual studio code
-            "code": f"W{self.message_id[1:]}",
+            "code": f"{self.message_id}",
             "text": f"[{self.tool}] {self.message}",
         }
         if self.extramessage:
@@ -98,7 +98,7 @@ class Linter:
             return [
                 LinterMessage(
                     tool="whatalinter",
-                    message_id=f"E999",
+                    message_id="E999",
                     filename=str(filepath),
                     lineno=1,
                     charno=1,
@@ -117,7 +117,7 @@ class Linter:
     def _execute_command(cls, args):
         """Execute the linter or raise LinterNotFound."""
         try:
-            return subprocess.run(
+            return subprocess.run(  # noqa: S603
                 args,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
@@ -144,27 +144,31 @@ class Linter:
             for param, value in kwargs.items():
                 setattr(message, param, value)
         else:
-            print("ERROR parsing", line)
+            print("ERROR parsing:", line)
         return message
 
     @classmethod
     def _parse_output(cls, output):
         messages = []
-        message = ""
+        message = None
         regex_index = 0
         for line in output.splitlines():
-            if regex_index == 0:
-                message = cls._parse_line(
-                    line, cls.regex[regex_index], None, tool=cls.name
-                )
-            else:
-                message = cls._parse_line(
-                    line, cls.regex[regex_index], message
-                )
+            message = cls._parse_line(
+                line, cls.regex[regex_index], message, tool=cls.name,
+            )
+
+            if isinstance(message, LinterMessage):
+                if regex_index == len(cls.regex) - 1:
+                    regex_index = 0
+                    if not cls.filter_out(message):
+                        messages.append(message)
+                    message = None
+                else:
+                    regex_index += 1
 
-            if regex_index == len(cls.regex) - 1:
-                regex_index = 0
-                messages.append(message)
-            else:
-                regex_index += 1
         return messages
+
+    @staticmethod
+    def filter_out(message: LinterMessage) -> bool:
+        """Return True when message should be ignored."""
+        return False
